@@ -145,6 +145,7 @@ def zones_settings(self):
     self.add('AUTH', 'zones', 'settings/development_mode')
     self.add('AUTH', 'zones', 'settings/early_hints')
     self.add('AUTH', 'zones', 'settings/email_obfuscation')
+    self.add('AUTH', 'zones', 'settings/fonts')
     self.add('AUTH', 'zones', 'settings/h2_prioritization')
     self.add('AUTH', 'zones', 'settings/hotlink_protection')
     self.add('AUTH', 'zones', 'settings/http2')
@@ -231,7 +232,7 @@ def zones_logpush(self):
     self.add('VOID', 'zones', 'logpush/datasets')
     self.add('AUTH', 'zones', 'logpush/datasets', 'fields')
     self.add('AUTH', 'zones', 'logpush/datasets', 'jobs')
-    self.add('VOID', 'zones', 'logpush/edge')
+    self.add('AUTH', 'zones', 'logpush/edge')
     self.add('AUTH', 'zones', 'logpush/edge/jobs')
     self.add('AUTH', 'zones', 'logpush/jobs')
     self.add('AUTH', 'zones', 'logpush/ownership')
@@ -377,14 +378,21 @@ def accounts(self):
     self.add('AUTH', 'accounts')
     self.add('VOID', 'accounts', 'billing')
     self.add('AUTH', 'accounts', 'billing/profile')
+    self.add('VOID', 'accounts', 'brand-protection')
+    self.add('AUTH', 'accounts', 'brand-protection/submit')
+    self.add('AUTH', 'accounts', 'brand-protection/url-info')
     self.add('AUTH', 'accounts', 'cfd_tunnel')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'configurations')
+    self.add('AUTH', 'accounts', 'cfd_tunnel', 'connectors')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'connections')
+    self.add('AUTH', 'accounts', 'cfd_tunnel', 'management')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'token')
     self.add('AUTH', 'accounts', 'custom_pages')
+
     self.add('VOID', 'accounts', 'dlp')
     self.add('VOID', 'accounts', 'dlp/patterns')
     self.add('AUTH', 'accounts', 'dlp/patterns/validate')
+    self.add('AUTH', 'accounts', 'dlp/payload_log')
     self.add('AUTH', 'accounts', 'dlp/profiles')
     self.add('AUTH', 'accounts', 'dlp/profiles/custom')
     self.add('AUTH', 'accounts', 'dlp/profiles/predefined')
@@ -406,11 +414,22 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'rules/lists/bulk_operations')
     self.add('AUTH', 'accounts', 'rulesets')
     self.add('AUTH', 'accounts', 'rulesets', 'versions')
+    self.add('AUTH', 'accounts', 'rulesets', 'versions', 'by_tag')
+    self.add('AUTH', 'accounts', 'rulesets', 'versions', 'by_tag/wordpress')
     self.add('AUTH', 'accounts', 'rulesets', 'rules')
 #   self.add('AUTH', 'accounts', 'rulesets/import')
     self.add('VOID', 'accounts', 'rulesets/phases')
     self.add('AUTH', 'accounts', 'rulesets/phases', 'entrypoint')
     self.add('AUTH', 'accounts', 'rulesets/phases', 'entrypoint/versions')
+    self.add('AUTH', 'accounts', 'rulesets/phases', 'versions')
+
+    self.add('VOID', 'accounts', 'rum')
+    self.add('AUTH', 'accounts', 'rum/site_info')
+    self.add('AUTH', 'accounts', 'rum/site_info/list')
+    self.add('VOID', 'accounts', 'rum/v2')
+    self.add('AUTH', 'accounts', 'rum/v2', 'rule')
+    self.add('AUTH', 'accounts', 'rum/v2', 'rules')
+
     self.add('VOID', 'accounts', 'storage')
     self.add('AUTH', 'accounts', 'storage/analytics')
     self.add('AUTH', 'accounts', 'storage/analytics/stored')
@@ -420,24 +439,48 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'keys')
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'values')
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'metadata')
+
     self.add('AUTH', 'accounts', 'subscriptions')
     self.add('AUTH', 'accounts', 'tunnels')
     self.add('AUTH', 'accounts', 'tunnels', 'connections')
+
+    self.add('VOID', 'accounts', 'vectorize')
+    self.add('AUTH', 'accounts', 'vectorize/index')
+    self.add('AUTH', 'accounts', 'vectorize/indexes')
+
     self.add('AUTH', 'accounts', 'virtual_dns')
     self.add('VOID', 'accounts', 'virtual_dns', 'dns_analytics')
     self.add('AUTH', 'accounts', 'virtual_dns', 'dns_analytics/report')
     self.add('AUTH', 'accounts', 'virtual_dns', 'dns_analytics/report/bytime')
+
     self.add('VOID', 'accounts', 'workers')
     self.add('AUTH', 'accounts', 'workers/account-settings')
+    self.add('VOID', 'accounts', 'workers/deployments')
+    self.add('AUTH', 'accounts', 'workers/deployments/by-script')
+    self.add('AUTH', 'accounts', 'workers/deployments/by-script', 'detail')
+    self.add('VOID', 'accounts', 'workers/dispatch')
+    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces')
+    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts')
+    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'content')
+    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'settings')
+    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'tags')
     self.add('AUTH', 'accounts', 'workers/domains')
     self.add('VOID', 'accounts', 'workers/durable_objects')
     self.add('AUTH', 'accounts', 'workers/durable_objects/namespaces')
     self.add('AUTH', 'accounts', 'workers/durable_objects/namespaces', 'objects')
     self.add('AUTH', 'accounts', 'workers/queues')
+    self.add('AUTH', 'accounts', 'workers/queues', 'consumers')
     self.add('AUTH', 'accounts', 'workers/scripts')
+    self.add('AUTH', 'accounts', 'workers/scripts', 'content')
+    self.add('AUTH', 'accounts', 'workers/scripts', 'content/v2')
     self.add('AUTH', 'accounts', 'workers/scripts', 'schedules')
+    self.add('AUTH', 'accounts', 'workers/scripts', 'settings')
     self.add('AUTH', 'accounts', 'workers/scripts', 'tails')
     self.add('AUTH', 'accounts', 'workers/scripts', 'usage-model')
+    self.add('VOID', 'accounts', 'workers/services')
+    self.add('VOID', 'accounts', 'workers/services', 'environments')
+    self.add('AUTH', 'accounts', 'workers/services', 'environments', 'content')
+    self.add('AUTH', 'accounts', 'workers/services', 'environments', 'settings')
     self.add('AUTH', 'accounts', 'workers/subdomain')
 
 def accounts_addressing(self):
@@ -452,8 +495,11 @@ def accounts_addressing(self):
     self.add('AUTH', 'accounts', 'addressing/loa_documents', 'download')
     self.add('AUTH', 'accounts', 'addressing/prefixes')
     self.add('VOID', 'accounts', 'addressing/prefixes', 'bgp')
+    self.add('AUTH', 'accounts', 'addressing/prefixes', 'bgp/prefixes')
     self.add('AUTH', 'accounts', 'addressing/prefixes', 'bgp/status')
+    self.add('AUTH', 'accounts', 'addressing/prefixes', 'bindings')
     self.add('AUTH', 'accounts', 'addressing/prefixes', 'delegations')
+    self.add('AUTH', 'accounts', 'addressing/services')
 
 def accounts_audit_logs(self):
     """ accounts audit_logs """
@@ -497,6 +543,8 @@ def accounts_stream(self):
     """ accounts stream """
 
     self.add('AUTH', 'accounts', 'stream')
+    self.add('AUTH', 'accounts', 'stream', 'audio')
+    self.add('AUTH', 'accounts', 'stream', 'audio/copy')
     self.add('AUTH', 'accounts', 'stream', 'captions')
     self.add('AUTH', 'accounts', 'stream', 'embed')
     self.add('AUTH', 'accounts', 'stream', 'downloads')
@@ -538,6 +586,7 @@ def zones_access(self):
     self.add('AUTH', 'zones', 'access/apps', 'revoke_tokens')
     self.add('AUTH', 'zones', 'access/bookmarks')
     self.add('AUTH', 'zones', 'access/certificates')
+    self.add('AUTH', 'zones', 'access/certificates/settings')
 #   self.add('AUTH', 'zones', 'access/apps/ca')
     self.add('AUTH', 'zones', 'access/apps', 'ca')
     self.add('AUTH', 'zones', 'access/apps', 'user_policy_checks')
@@ -552,6 +601,7 @@ def accounts_access(self):
 
     self.add('VOID', 'accounts', 'access')
 #   self.add('AUTH', 'accounts', 'access/bookmarks') # deprecated 2023-03-19
+    self.add('AUTH', 'accounts', 'access/custom_pages')
     self.add('AUTH', 'accounts', 'access/gateway_ca')
     self.add('AUTH', 'accounts', 'access/groups')
     self.add('AUTH', 'accounts', 'access/identity_providers')
@@ -568,6 +618,7 @@ def accounts_access(self):
     self.add('AUTH', 'accounts', 'access/apps', 'revoke_tokens')
     self.add('AUTH', 'accounts', 'access/apps', 'user_policy_checks')
     self.add('AUTH', 'accounts', 'access/certificates')
+    self.add('AUTH', 'accounts', 'access/certificates/settings')
     self.add('AUTH', 'accounts', 'access/keys')
     self.add('AUTH', 'accounts', 'access/keys/rotate')
     self.add('VOID', 'accounts', 'access/logs')
@@ -591,6 +642,7 @@ def zones_waiting_rooms(self):
     self.add('AUTH', 'zones', 'waiting_rooms', 'rules')
     self.add('AUTH', 'zones', 'waiting_rooms', 'status')
     self.add('AUTH', 'zones', 'waiting_rooms/preview')
+    self.add('AUTH', 'zones', 'waiting_rooms/settings')
 
 def accounts_extras(self):
     """ extras """
@@ -610,18 +662,34 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'custom_ns/verify')
 
     self.add('AUTH', 'accounts', 'devices')
+
     self.add('AUTH', 'accounts', 'devices', 'override_codes')
+    self.add('AUTH', 'accounts', 'devices/dex_tests')
+    self.add('AUTH', 'accounts', 'devices/networks')
     self.add('AUTH', 'accounts', 'devices/policies')
     self.add('AUTH', 'accounts', 'devices/policy')
     self.add('AUTH', 'accounts', 'devices/policy', 'exclude')
+#   self.add('AUTH', 'accounts', 'devices/policy/exclude')
     self.add('AUTH', 'accounts', 'devices/policy', 'fallback_domains')
+#   self.add('AUTH', 'accounts', 'devices/policy/fallback_domains')
     self.add('AUTH', 'accounts', 'devices/policy', 'include')
+#   self.add('AUTH', 'accounts', 'devices/policy/include')
     self.add('AUTH', 'accounts', 'devices/posture')
     self.add('AUTH', 'accounts', 'devices/posture/integration')
     self.add('AUTH', 'accounts', 'devices/revoke')
     self.add('AUTH', 'accounts', 'devices/settings')
     self.add('AUTH', 'accounts', 'devices/unrevoke')
 
+    self.add('VOID', 'accounts', 'dex')
+    self.add('AUTH', 'accounts', 'dex/colos')
+    self.add('AUTH', 'accounts', 'dex/http-tests')
+    self.add('AUTH', 'accounts', 'dex/tests')
+    self.add('AUTH', 'accounts', 'dex/tests/unique-devices')
+    self.add('VOID', 'accounts', 'dex/traceroute-test-results')
+    self.add('AUTH', 'accounts', 'dex/traceroute-test-results', 'network-path')
+    self.add('AUTH', 'accounts', 'dex/traceroute-tests')
+    self.add('AUTH', 'accounts', 'dex/traceroute-tests', 'network-path')
+
     self.add('AUTH', 'accounts', 'dns_firewall')
     self.add('VOID', 'accounts', 'dns_firewall', 'dns_analytics')
     self.add('AUTH', 'accounts', 'dns_firewall', 'dns_analytics/report')
@@ -641,10 +709,11 @@ def accounts_extras(self):
     self.add('VOID', 'accounts', 'images')
     self.add('AUTH', 'accounts', 'images/v1')
     self.add('AUTH', 'accounts', 'images/v1', 'blob')
+    self.add('AUTH', 'accounts', 'images/v1/config')
     self.add('AUTH', 'accounts', 'images/v1/keys')
     self.add('AUTH', 'accounts', 'images/v1/stats')
     self.add('AUTH', 'accounts', 'images/v1/variants')
-    self.add('VOID', 'accounts', 'images/v2')
+    self.add('AUTH', 'accounts', 'images/v2')
     self.add('AUTH', 'accounts', 'images/v2/direct_upload')
 
     self.add('VOID', 'accounts', 'intel')
@@ -656,6 +725,13 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'intel/domain')
     self.add('AUTH', 'accounts', 'intel/domain-history')
     self.add('AUTH', 'accounts', 'intel/domain/bulk')
+    self.add('AUTH', 'accounts', 'intel/indicator-feeds')
+    self.add('AUTH', 'accounts', 'intel/indicator-feeds', 'data')
+    self.add('AUTH', 'accounts', 'intel/indicator-feeds', 'snapshot')
+    self.add('VOID', 'accounts', 'intel/indicator-feeds/permissions')
+    self.add('AUTH', 'accounts', 'intel/indicator-feeds/permissions/add')
+    self.add('AUTH', 'accounts', 'intel/indicator-feeds/permissions/remove')
+    self.add('AUTH', 'accounts', 'intel/indicator-feeds/permissions/view')
     self.add('AUTH', 'accounts', 'intel/ip')
     self.add('AUTH', 'accounts', 'intel/ip-list')
     self.add('AUTH', 'accounts', 'intel/miscategorization')
@@ -676,6 +752,7 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'pages/projects', 'deployments', 'retry')
     self.add('AUTH', 'accounts', 'pages/projects', 'deployments', 'rollback')
     self.add('AUTH', 'accounts', 'pages/projects', 'domains')
+    self.add('AUTH', 'accounts', 'pages/projects', 'purge_build_cache')
 
     self.add('AUTH', 'accounts', 'pcaps')
     self.add('AUTH', 'accounts', 'pcaps', 'download')
@@ -688,6 +765,15 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'teamnet/routes/network')
     self.add('AUTH', 'accounts', 'teamnet/virtual_networks')
 
+    self.add('VOID', 'accounts', 'urlscanner')
+    self.add('AUTH', 'accounts', 'urlscanner/scan')
+    self.add('AUTH', 'accounts', 'urlscanner/scan', 'har')
+    self.add('AUTH', 'accounts', 'urlscanner/scan', 'screenshot')
+
+    self.add('VOID', 'accounts', 'hyperdrive')
+    self.add('AUTH', 'accounts', 'hyperdrive/configs')
+
+
 def zones_extras(self):
     """ zones extras """
 
@@ -696,8 +782,11 @@ def zones_extras(self):
     self.add('VOID', 'zones', 'cache')
     self.add('AUTH', 'zones', 'cache/variants')
     self.add('AUTH', 'zones', 'cache/cache_reserve')
+    self.add('AUTH', 'zones', 'cache/regional_tiered_cache')
+    self.add('AUTH', 'zones', 'cache/tiered_cache_smart_topology_enable')
     self.add('AUTH', 'zones', 'managed_headers')
     self.add('AUTH', 'zones', 'page_shield')
+    self.add('AUTH', 'zones', 'page_shield/policies')
     self.add('AUTH', 'zones', 'page_shield/scripts')
     self.add('AUTH', 'zones', 'page_shield/connections')
     self.add('AUTH', 'zones', 'rulesets')
@@ -708,8 +797,25 @@ def zones_extras(self):
     self.add('AUTH', 'zones', 'rulesets/phases', 'entrypoint/versions')
     self.add('VOID', 'zones', 'rulesets/phases/http_custom_errors')
     self.add('AUTH', 'zones', 'rulesets/phases/http_custom_errors/entrypoint')
+    self.add('AUTH', 'zones', 'rulesets/phases', 'versions')
     self.add('AUTH', 'zones', 'url_normalization')
 
+    self.add('VOID', 'zones', 'hostnames')
+    self.add('AUTH', 'zones', 'hostnames/settings')
+    self.add('AUTH', 'zones', 'snippets')
+    self.add('AUTH', 'zones', 'snippets', 'content')
+    self.add('AUTH', 'zones', 'snippets/snippet_rules')
+
+    self.add('VOID', 'zones', 'speed_api')
+    self.add('AUTH', 'zones', 'speed_api/availabilities')
+    self.add('AUTH', 'zones', 'speed_api/pages')
+    self.add('AUTH', 'zones', 'speed_api/pages', 'tests')
+    self.add('AUTH', 'zones', 'speed_api/pages', 'trend')
+    self.add('AUTH', 'zones', 'speed_api/schedule')
+
+    self.add('VOID', 'zones', 'dcv_delegation')
+    self.add('AUTH', 'zones', 'dcv_delegation/uuid')
+
 def zones_web3(self):
     """ zones web3 """
 
@@ -756,15 +862,66 @@ def zones_api_gateway(self):
 
 def radar(self):
     """ radar """
+
     self.add('VOID', 'radar')
+    self.add('AUTH', 'radar/alerts')
+    self.add('AUTH', 'radar/alerts/locations')
     self.add('VOID', 'radar/annotations')
     self.add('AUTH', 'radar/annotations/outages')
     self.add('AUTH', 'radar/annotations/outages/locations')
+
+    self.add('VOID', 'radar/as112')
+    self.add('VOID', 'radar/as112/summary')
+    self.add('AUTH', 'radar/as112/summary/dnssec')
+    self.add('AUTH', 'radar/as112/summary/edns')
+    self.add('AUTH', 'radar/as112/summary/ip_version')
+    self.add('AUTH', 'radar/as112/summary/protocol')
+    self.add('AUTH', 'radar/as112/summary/query_type')
+    self.add('AUTH', 'radar/as112/summary/response_codes')
+
+    self.add('AUTH', 'radar/as112/timeseries')
+    self.add('AUTH', 'radar/as112/timeseries/dnssec')
+    self.add('AUTH', 'radar/as112/timeseries/edns')
+    self.add('AUTH', 'radar/as112/timeseries/ip_version')
+    self.add('AUTH', 'radar/as112/timeseries/protocol')
+    self.add('AUTH', 'radar/as112/timeseries/query_type')
+    self.add('AUTH', 'radar/as112/timeseries/response_codes')
+
+    self.add('VOID', 'radar/as112/timeseries_groups')
+    self.add('AUTH', 'radar/as112/timeseries_groups/dnssec')
+    self.add('AUTH', 'radar/as112/timeseries_groups/edns')
+    self.add('AUTH', 'radar/as112/timeseries_groups/ip_version')
+    self.add('AUTH', 'radar/as112/timeseries_groups/protocol')
+    self.add('AUTH', 'radar/as112/timeseries_groups/query_type')
+    self.add('AUTH', 'radar/as112/timeseries_groups/response_codes')
+
+    self.add('VOID', 'radar/as112/top')
+    self.add('AUTH', 'radar/as112/top/locations')
+    self.add('AUTH', 'radar/as112/top/locations/dnssec')
+    self.add('AUTH', 'radar/as112/top/locations/edns')
+    self.add('AUTH', 'radar/as112/top/locations/ip_version')
+
     self.add('VOID', 'radar/attacks')
     self.add('VOID', 'radar/attacks/layer3')
     self.add('AUTH', 'radar/attacks/layer3/summary')
     self.add('AUTH', 'radar/attacks/layer3/timeseries')
     self.add('AUTH', 'radar/attacks/layer3/timeseries_groups')
+    self.add('AUTH', 'radar/attacks/layer3/summary/bitrate')
+    self.add('AUTH', 'radar/attacks/layer3/summary/duration')
+    self.add('AUTH', 'radar/attacks/layer3/summary/ip_version')
+    self.add('AUTH', 'radar/attacks/layer3/summary/protocol')
+    self.add('AUTH', 'radar/attacks/layer3/summary/vector')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/bitrate')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/duration')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/industry')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/ip_version')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/protocol')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/vector')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/vertical')
+    self.add('VOID', 'radar/attacks/layer3/top')
+    self.add('AUTH', 'radar/attacks/layer3/top/industry')
+    self.add('AUTH', 'radar/attacks/layer3/top/vertical')
+
     self.add('VOID', 'radar/attacks/layer7')
     self.add('AUTH', 'radar/attacks/layer7/summary')
     self.add('AUTH', 'radar/attacks/layer7/timeseries')
@@ -776,20 +933,81 @@ def radar(self):
     self.add('VOID', 'radar/attacks/layer7/top/locations')
     self.add('AUTH', 'radar/attacks/layer7/top/locations/origin')
     self.add('AUTH', 'radar/attacks/layer7/top/locations/target')
+
     self.add('VOID', 'radar/bgp')
+    self.add('VOID', 'radar/bgp/leaks')
+    self.add('AUTH', 'radar/bgp/leaks/events')
     self.add('AUTH', 'radar/bgp/timeseries')
     self.add('VOID', 'radar/bgp/top')
     self.add('AUTH', 'radar/bgp/top/ases')
+    self.add('AUTH', 'radar/bgp/top/ases/prefixes')
     self.add('AUTH', 'radar/bgp/top/prefixes')
+    self.add('VOID', 'radar/bgp/hijacks')
+    self.add('AUTH', 'radar/bgp/hijacks/events')
+    self.add('VOID', 'radar/bgp/routes')
+    self.add('AUTH', 'radar/bgp/routes/moas')
+    self.add('AUTH', 'radar/bgp/routes/pfx2as')
+    self.add('AUTH', 'radar/bgp/routes/stats')
+
+    self.add('AUTH', 'radar/datasets')
+    self.add('AUTH', 'radar/datasets/download')
+
     self.add('VOID', 'radar/dns')
-    self.add('AUTH', 'radar/dns/timeseries')
     self.add('VOID', 'radar/dns/top')
     self.add('AUTH', 'radar/dns/top/ases')
     self.add('AUTH', 'radar/dns/top/locations')
+
+    self.add('VOID', 'radar/email')
+    self.add('VOID', 'radar/email/security')
+    self.add('VOID', 'radar/email/security/summary')
+    self.add('AUTH', 'radar/email/security/summary/arc')
+    self.add('AUTH', 'radar/email/security/summary/dkim')
+    self.add('AUTH', 'radar/email/security/summary/dmarc')
+    self.add('AUTH', 'radar/email/security/summary/malicious')
+    self.add('AUTH', 'radar/email/security/summary/spam')
+    self.add('AUTH', 'radar/email/security/summary/spf')
+    self.add('AUTH', 'radar/email/security/summary/threat_category')
+    self.add('VOID', 'radar/email/security/timeseries')
+    self.add('AUTH', 'radar/email/security/timeseries/arc')
+    self.add('AUTH', 'radar/email/security/timeseries/dkim')
+    self.add('AUTH', 'radar/email/security/timeseries/dmarc')
+    self.add('AUTH', 'radar/email/security/timeseries/malicious')
+    self.add('AUTH', 'radar/email/security/timeseries/spam')
+    self.add('AUTH', 'radar/email/security/timeseries/spf')
+    self.add('AUTH', 'radar/email/security/timeseries/threat_category')
+
+    self.add('VOID', 'radar/email/security/timeseries_groups')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/arc')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/dkim')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/dmarc')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/malicious')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/spam')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/spf')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/threat_category')
+
+    self.add('VOID', 'radar/email/security/top')
+    self.add('AUTH', 'radar/email/security/top/ases')
+    self.add('AUTH', 'radar/email/security/top/ases/arc')
+    self.add('AUTH', 'radar/email/security/top/ases/dkim')
+    self.add('AUTH', 'radar/email/security/top/ases/dmarc')
+    self.add('AUTH', 'radar/email/security/top/ases/malicious')
+    self.add('AUTH', 'radar/email/security/top/ases/spam')
+    self.add('AUTH', 'radar/email/security/top/ases/spf')
+    self.add('AUTH', 'radar/email/security/top/locations')
+    self.add('AUTH', 'radar/email/security/top/locations/arc')
+    self.add('AUTH', 'radar/email/security/top/locations/dkim')
+    self.add('AUTH', 'radar/email/security/top/locations/dmarc')
+    self.add('AUTH', 'radar/email/security/top/locations/malicious')
+    self.add('AUTH', 'radar/email/security/top/locations/spam')
+    self.add('AUTH', 'radar/email/security/top/locations/spf')
+
     self.add('VOID', 'radar/entities')
     self.add('AUTH', 'radar/entities/asns')
+    self.add('AUTH', 'radar/entities/asns', 'rel')
     self.add('AUTH', 'radar/entities/asns/ip')
+    self.add('AUTH', 'radar/entities/ip')
     self.add('AUTH', 'radar/entities/locations')
+
     self.add('VOID', 'radar/http')
     self.add('VOID', 'radar/http/summary')
     self.add('AUTH', 'radar/http/summary/bot_class')
@@ -797,6 +1015,7 @@ def radar(self):
     self.add('AUTH', 'radar/http/summary/http_protocol')
     self.add('AUTH', 'radar/http/summary/http_version')
     self.add('AUTH', 'radar/http/summary/ip_version')
+    self.add('AUTH', 'radar/http/summary/os')
     self.add('AUTH', 'radar/http/summary/tls_version')
     self.add('VOID', 'radar/http/timeseries')
     self.add('AUTH', 'radar/http/timeseries/bot_class')
@@ -806,6 +1025,7 @@ def radar(self):
     self.add('AUTH', 'radar/http/timeseries/http_protocol')
     self.add('AUTH', 'radar/http/timeseries/http_version')
     self.add('AUTH', 'radar/http/timeseries/ip_version')
+    self.add('AUTH', 'radar/http/timeseries/os')
     self.add('AUTH', 'radar/http/timeseries/tls_version')
     self.add('VOID', 'radar/http/top')
     self.add('AUTH', 'radar/http/top/ases')
@@ -814,6 +1034,7 @@ def radar(self):
     self.add('AUTH', 'radar/http/top/ases/http_protocol')
     self.add('AUTH', 'radar/http/top/ases/http_version')
     self.add('AUTH', 'radar/http/top/ases/ip_version')
+    self.add('AUTH', 'radar/http/top/ases/os')
     self.add('AUTH', 'radar/http/top/ases/tls_version')
     self.add('AUTH', 'radar/http/top/browsers')
     self.add('AUTH', 'radar/http/top/browser_families')
@@ -823,39 +1044,86 @@ def radar(self):
     self.add('AUTH', 'radar/http/top/locations/http_protocol')
     self.add('AUTH', 'radar/http/top/locations/http_version')
     self.add('AUTH', 'radar/http/top/locations/ip_version')
+    self.add('AUTH', 'radar/http/top/locations/os')
     self.add('AUTH', 'radar/http/top/locations/tls_version')
+
     self.add('VOID', 'radar/netflows')
     self.add('AUTH', 'radar/netflows/timeseries')
     self.add('VOID', 'radar/netflows/top')
     self.add('AUTH', 'radar/netflows/top/ases')
     self.add('AUTH', 'radar/netflows/top/locations')
+
+    self.add('VOID', 'radar/performance')
+    self.add('VOID', 'radar/performance/iqi')
+    self.add('AUTH', 'radar/performance/iqi/summary')
+    self.add('AUTH', 'radar/performance/iqi/timeseries_groups')
+
+    self.add('VOID', 'radar/quality')
+    self.add('VOID', 'radar/quality/iqi')
+    self.add('AUTH', 'radar/quality/iqi/summary')
+    self.add('AUTH', 'radar/quality/iqi/timeseries_groups')
+    self.add('VOID', 'radar/quality/speed')
+    self.add('AUTH', 'radar/quality/speed/histogram')
+    self.add('AUTH', 'radar/quality/speed/summary')
+    self.add('VOID', 'radar/quality/speed/top')
+    self.add('AUTH', 'radar/quality/speed/top/ases')
+    self.add('AUTH', 'radar/quality/speed/top/locations')
+
     self.add('VOID', 'radar/ranking')
+    self.add('AUTH', 'radar/ranking/domain')
     self.add('AUTH', 'radar/ranking/timeseries')
+    self.add('AUTH', 'radar/ranking/timeseries_groups')
     self.add('AUTH', 'radar/ranking/top')
-    self.add('VOID', 'radar/reports')
-    self.add('AUTH', 'radar/reports/datasets')
-    self.add('AUTH', 'radar/reports/datasets/download')
+
     self.add('VOID', 'radar/search')
     self.add('AUTH', 'radar/search/global')
+
     self.add('AUTH', 'radar/specialevents')
+
+    self.add('VOID', 'radar/http/timeseries_groups')
+    self.add('AUTH', 'radar/http/timeseries_groups/bot_class')
+    self.add('AUTH', 'radar/http/timeseries_groups/browser')
+    self.add('AUTH', 'radar/http/timeseries_groups/browser_family')
+    self.add('AUTH', 'radar/http/timeseries_groups/device_type')
+    self.add('AUTH', 'radar/http/timeseries_groups/http_protocol')
+    self.add('AUTH', 'radar/http/timeseries_groups/http_version')
+    self.add('AUTH', 'radar/http/timeseries_groups/ip_version')
+    self.add('AUTH', 'radar/http/timeseries_groups/os')
+    self.add('AUTH', 'radar/http/timeseries_groups/tls_version')
+
     self.add('VOID', 'radar/verified_bots')
     self.add('VOID', 'radar/verified_bots/top')
     self.add('AUTH', 'radar/verified_bots/top/bots')
     self.add('AUTH', 'radar/verified_bots/top/categories')
 
+    self.add('VOID', 'radar/connection_tampering')
+    self.add('AUTH', 'radar/connection_tampering/summary')
+    self.add('AUTH', 'radar/connection_tampering/timeseries_groups')
+    self.add('AUTH', 'radar/traffic_anomalies')
+    self.add('AUTH', 'radar/traffic_anomalies/locations')
+
 def from_developers(self):
     """ from_developers """
     self.add('VOID', 'accounts', 'analytics_engine')
     self.add('AUTH', 'accounts', 'analytics_engine/sql')
 
-    self.add('AUTH', 'accounts', 'images/v1/config')
-#   self.add('AUTH', 'accounts', 'images/v1/direct_upload') # deprecated 2022-07-01 - expired!
-
     self.add('VOID', 'accounts', 'logpush')
     self.add('AUTH', 'accounts', 'logpush/jobs')
+    self.add('VOID', 'accounts', 'logpush/datasets')
+    self.add('AUTH', 'accounts', 'logpush/datasets', 'fields')
+    self.add('AUTH', 'accounts', 'logpush/datasets', 'jobs')
+    self.add('AUTH', 'accounts', 'logpush/ownership')
+    self.add('AUTH', 'accounts', 'logpush/ownership/validate')
+    self.add('VOID', 'accounts', 'logpush/validate')
+    self.add('VOID', 'accounts', 'logpush/validate/destination')
+    self.add('AUTH', 'accounts', 'logpush/validate/destination/exists')
+    self.add('AUTH', 'accounts', 'logpush/validate/origin')
 
     self.add('VOID', 'accounts', 'logs')
     self.add('AUTH', 'accounts', 'logs/retrieve')
+    self.add('VOID', 'accounts', 'logs/control')
+    self.add('VOID', 'accounts', 'logs/control/cmb')
+    self.add('AUTH', 'accounts', 'logs/control/cmb/config')
 
     self.add('VOID', 'accounts', 'magic/advanced_tcp_protection')
     self.add('VOID', 'accounts', 'magic/advanced_tcp_protection/configs')
@@ -873,8 +1141,6 @@ def from_developers(self):
     self.add('AUTH', 'accounts', 'pubsub/namespaces', 'brokers')
     self.add('AUTH', 'accounts', 'pubsub/namespaces', 'brokers', 'credentials')
 
-    self.add('VOID', 'accounts', 'rulesets', 'versions', 'by_tag')
-    self.add('AUTH', 'accounts', 'rulesets', 'versions', 'by_tag/wordpress')
     self.add('VOID', 'accounts', 'rulesets/phases/ddos_l4')
     self.add('AUTH', 'accounts', 'rulesets/phases/ddos_l4/entrypoint')
     self.add('VOID', 'accounts', 'rulesets/phases/ddos_l7')
@@ -887,11 +1153,7 @@ def from_developers(self):
     self.add('VOID', 'accounts', 'stream/analytics')
     self.add('AUTH', 'accounts', 'stream/analytics/views')
     self.add('AUTH', 'accounts', 'stream/live_inputs', 'videos')
-
-    self.add('VOID', 'accounts', 'workers/dispatch')
-    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces')
-    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts')
-    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'tags')
+    self.add('AUTH', 'accounts', 'stream/storage-usage')
 
 #   self.add('AUTH', 'organizations', 'load_balancers/monitors')
 
@@ -918,3 +1180,15 @@ def from_developers(self):
     self.add('VOID', 'zones', 'rulesets/phases/http_request_firewall_managed')
     self.add('AUTH', 'zones', 'rulesets/phases/http_request_firewall_managed/entrypoint')
     self.add('AUTH', 'zones', 'rulesets/phases/http_request_firewall_managed/entrypoint/versions')
+
+    self.add('VOID', 'zones', 'certificate_authorities')
+    self.add('AUTH', 'zones', 'certificate_authorities/hostname_associations')
+    self.add('AUTH', 'zones', 'hold')
+
+    self.add('VOID', 'accounts', 'challenges')
+    self.add('AUTH', 'accounts', 'challenges/widgets')
+    self.add('AUTH', 'accounts', 'challenges/widgets', 'rotate_secret')
+    self.add('AUTH', 'accounts', 'mtls_certificates')
+    self.add('AUTH', 'accounts', 'mtls_certificates', 'associations')
+    self.add('VOID', 'accounts', 'request-tracer')
+    self.add('AUTH', 'accounts', 'request-tracer/trace')
